/*
 * Copyright 2017-2024 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package example.micronaut;

import org.testcontainers.containers.GenericContainer;

class FakeGcsServerContainer extends GenericContainer<FakeGcsServerContainer> {

    private static final String DEFAULT_IMAGE_NAME = "fsouza/fake-gcs-server:1.40.1";
    private static final int DEFAULT_PORT = 4443;

    public FakeGcsServerContainer() {
        super(DEFAULT_IMAGE_NAME);
        this.withExposedPorts(DEFAULT_PORT)
                .withCreateContainerCmdModifier(cmd -> cmd.withEntrypoint("/bin/fake-gcs-server", "-scheme", "http"));
    }

    public String getUrl() {
        if (!isRunning()) {
            start();
        }
        return String.format("http://%s:%s", getHost(), getMappedPort(DEFAULT_PORT));
    }
}
